@@ -1,7 +1,7 @@
 -- -
 -- #%L
 -- %%
--- Copyright (C) 2005 - 2025 Kuali, Inc. - All Rights Reserved
+-- Copyright (C) 2005 - 2026 Kuali, Inc. - All Rights Reserved
 -- %%
 -- You may use and modify this code under the terms of the Kuali, Inc.
 -- Pre-Release License Agreement. You may not distribute it.
@@ -11,6 +11,14 @@
 -- #L%
 -- -
 
+ALTER TABLE SUBAWARD_TEMPLATE_INFO
+  ADD COLUMN (
+  DATA_SHARING_CD VARCHAR(4));
+
+ALTER TABLE SUBAWARD_TEMPLATE_INFO
+  ADD COLUMN (
+  IRB_IACUC_CONTACT DECIMAL(3, 0));
+
 UPDATE subaward_forms
 SET form = NULL
-WHERE FORM_ID = 'FDP Agreement';
+WHERE FORM_ID = 'FDP_ATT_3A';
