@@ -13,6 +13,9 @@
 
 DELIMITER /
 
-delete from krcr_parm_t where PARM_NM = 'CACHING_IND'
+delete from krcr_parm_t
+where nmspc_cd = 'KR-NS'
+and cmpnt_cd = 'All'
+and parm_nm in ('STRING_TO_DATE_FORMATS', 'STRING_TO_TIMESTAMP_FORMATS', 'TIMESTAMP_TO_STRING_FORMAT_FOR_USER_INTERFACE', 'DATE_TO_STRING_FORMAT_FOR_FILE_NAME', 'TIMESTAMP_TO_STRING_FORMAT_FOR_FILE_NAME')
 /
 DELIMITER ;
